@@ -18,13 +18,8 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_datapipeline.paginator import (
-    DescribeObjectsPaginator,
-    ListPipelinesPaginator,
-    QueryObjectsPaginator,
-)
-
-from .literals import TaskStatus
+from .literals import TaskStatusType
+from .paginator import DescribeObjectsPaginator, ListPipelinesPaginator, QueryObjectsPaginator
 from .type_defs import (
     CreatePipelineOutputTypeDef,
     DescribeObjectsOutputTypeDef,
@@ -75,7 +70,7 @@ class Exceptions:
 
 class DataPipelineClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -89,40 +84,40 @@ class DataPipelineClient:
         startTimestamp: datetime = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
-        [Show boto3-stubs documentation](./client.md#activate-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
+        [Show boto3-stubs documentation](./client.md#activate_pipeline)
         """
 
     def add_tags(self, pipelineId: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
-        [Show boto3-stubs documentation](./client.md#add-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
+        [Show boto3-stubs documentation](./client.md#add_tags)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_pipeline(
         self, name: str, uniqueId: str, description: str = None, tags: List["TagTypeDef"] = None
     ) -> CreatePipelineOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
-        [Show boto3-stubs documentation](./client.md#create-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
+        [Show boto3-stubs documentation](./client.md#create_pipeline)
         """
 
     def deactivate_pipeline(self, pipelineId: str, cancelActive: bool = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
-        [Show boto3-stubs documentation](./client.md#deactivate-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
+        [Show boto3-stubs documentation](./client.md#deactivate_pipeline)
         """
 
     def delete_pipeline(self, pipelineId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
-        [Show boto3-stubs documentation](./client.md#delete-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
+        [Show boto3-stubs documentation](./client.md#delete_pipeline)
         """
 
     def describe_objects(
@@ -133,22 +128,22 @@ class DataPipelineClient:
         marker: str = None,
     ) -> DescribeObjectsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
-        [Show boto3-stubs documentation](./client.md#describe-objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
+        [Show boto3-stubs documentation](./client.md#describe_objects)
         """
 
     def describe_pipelines(self, pipelineIds: List[str]) -> DescribePipelinesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
-        [Show boto3-stubs documentation](./client.md#describe-pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
+        [Show boto3-stubs documentation](./client.md#describe_pipelines)
         """
 
     def evaluate_expression(
         self, pipelineId: str, objectId: str, expression: str
     ) -> EvaluateExpressionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
-        [Show boto3-stubs documentation](./client.md#evaluate-expression)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
+        [Show boto3-stubs documentation](./client.md#evaluate_expression)
         """
 
     def generate_presigned_url(
@@ -159,22 +154,22 @@ class DataPipelineClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_pipeline_definition(
         self, pipelineId: str, version: str = None
     ) -> GetPipelineDefinitionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
-        [Show boto3-stubs documentation](./client.md#get-pipeline-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
+        [Show boto3-stubs documentation](./client.md#get_pipeline_definition)
         """
 
     def list_pipelines(self, marker: str = None) -> ListPipelinesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
-        [Show boto3-stubs documentation](./client.md#list-pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
+        [Show boto3-stubs documentation](./client.md#list_pipelines)
         """
 
     def poll_for_task(
@@ -184,8 +179,8 @@ class DataPipelineClient:
         instanceIdentity: InstanceIdentityTypeDef = None,
     ) -> PollForTaskOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
-        [Show boto3-stubs documentation](./client.md#poll-for-task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
+        [Show boto3-stubs documentation](./client.md#poll_for_task)
         """
 
     def put_pipeline_definition(
@@ -196,8 +191,8 @@ class DataPipelineClient:
         parameterValues: List["ParameterValueTypeDef"] = None,
     ) -> PutPipelineDefinitionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
-        [Show boto3-stubs documentation](./client.md#put-pipeline-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
+        [Show boto3-stubs documentation](./client.md#put_pipeline_definition)
         """
 
     def query_objects(
@@ -209,49 +204,49 @@ class DataPipelineClient:
         limit: int = None,
     ) -> QueryObjectsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
-        [Show boto3-stubs documentation](./client.md#query-objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
+        [Show boto3-stubs documentation](./client.md#query_objects)
         """
 
     def remove_tags(self, pipelineId: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
-        [Show boto3-stubs documentation](./client.md#remove-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
+        [Show boto3-stubs documentation](./client.md#remove_tags)
         """
 
     def report_task_progress(
         self, taskId: str, fields: List["FieldTypeDef"] = None
     ) -> ReportTaskProgressOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
-        [Show boto3-stubs documentation](./client.md#report-task-progress)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
+        [Show boto3-stubs documentation](./client.md#report_task_progress)
         """
 
     def report_task_runner_heartbeat(
         self, taskrunnerId: str, workerGroup: str = None, hostname: str = None
     ) -> ReportTaskRunnerHeartbeatOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
-        [Show boto3-stubs documentation](./client.md#report-task-runner-heartbeat)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
+        [Show boto3-stubs documentation](./client.md#report_task_runner_heartbeat)
         """
 
     def set_status(self, pipelineId: str, objectIds: List[str], status: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.set_status)
-        [Show boto3-stubs documentation](./client.md#set-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.set_status)
+        [Show boto3-stubs documentation](./client.md#set_status)
         """
 
     def set_task_status(
         self,
         taskId: str,
-        taskStatus: TaskStatus,
+        taskStatus: TaskStatusType,
         errorId: str = None,
         errorMessage: str = None,
         errorStackTrace: str = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
-        [Show boto3-stubs documentation](./client.md#set-task-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
+        [Show boto3-stubs documentation](./client.md#set_task_status)
         """
 
     def validate_pipeline_definition(
@@ -262,8 +257,8 @@ class DataPipelineClient:
         parameterValues: List["ParameterValueTypeDef"] = None,
     ) -> ValidatePipelineDefinitionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
-        [Show boto3-stubs documentation](./client.md#validate-pipeline-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
+        [Show boto3-stubs documentation](./client.md#validate_pipeline_definition)
         """
 
     @overload
@@ -271,17 +266,17 @@ class DataPipelineClient:
         self, operation_name: Literal["describe_objects"]
     ) -> DescribeObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)[Show boto3-stubs documentation](./paginators.md#describeobjectspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)[Show boto3-stubs documentation](./paginators.md#describeobjectspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_objects"]) -> QueryObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)[Show boto3-stubs documentation](./paginators.md#queryobjectspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)[Show boto3-stubs documentation](./paginators.md#queryobjectspaginator)
         """
